@@ -1,7 +1,4 @@
 """Django template tags for SatNOGS DB"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from django import template
 from django.urls import reverse
 from django.utils.html import format_html
